*------------------------------------------------------------------------------
* Procedure :  LoadImage
* Purpose   :  This procedure is used to replace the VFP LOADPICTURE function.
*              That function has a problem using BMPs that are compiled into
*              the EXE.  This function makes use of a table called GRAPHICS
*              that contains the BMPs that we need to load into an ImageList
*              control.  They are copied out to a temp file, loaded to an
*              object using LOADPICTURE, then the temp file is deleted.  This
*              is based on Doug Hennig's version.
* Programmer:  Russell Campbell
* Copyright :  The Interthink Consulting Group, Inc. - All Rights Reserved
* Date      :  03/13/2000
* Revisions :  
*------------------------------------------------------------------------------
procedure LoadImage
lparameters MyFileName, MyTable
	
	local CloseTable, RtnVal, TempFileName
	CloseTable = .f.
	RtnVal     = .NULL.
	
	if parameters() < 2
		MyTable = "graphics"
	endif
	
	if used(MyTable)
		select (MyTable)
	else
		CloseTable = .t.
		sele 0
		use (MyTable)
	endif
	
	locate for upper(name) == padr(upper(MyFileName), len(name))
	
	if found()
		TempFileName = sys(2023) + "\" + sys(2015) + "." + JustExt(alltrim(name))
		copy memo graphic to (TempFileName)
		RtnVal = LoadPicture(TempFileName)
		delete file (TempFileName)
	endif
	
	if CloseTable
		use in (MyTable)
	endif
	
return RtnVal
