*==============================================================================
* Program:			CreateShortcut
* Purpose:			Creates a shortcut to a file
* Author:			Doug Hennig
* Copyright:		(c) 2001 Stonefield Systems Group Inc.
* Last revision:	01/20/2001
* Parameters:		tcLinkFile   - the name of the shortcut file (including
*						path)
*					tcFileToLink - the file (including path) the shortcut is
*						for
* Returns:			.T. if the shortcut was created
* Environment in:	the file to link to must exist
* Environment out:	the shortcut was created
*==============================================================================

lparameters tcLinkFile, ;
	tcFileToLink
local lcLinkFile, ;
	lcFileToLink, ;
	lcDirectory, ;
	lnResult

* Ensure we have proper parameters.

assert vartype(tcLinkFile) = 'C' and not empty(tcLinkFile) ;
	message 'Invalid shortcut filename specified'
assert vartype(tcFileToLink) = 'C' and not empty(tcFileToLink) ;
	message 'Invalid link filename specified'

* Declare the functions we need to create a shortcut.

declare integer CreateShellLink in lnkfiles.dll ;
	string @lpzLinkFileName, string @lpzExeFileName
declare integer SetLinkWorkDir in lnkfiles.dll ;
	integer hWnd, string @lpszLinkName, string @lpszPath

* Create the shortcut.

lcLinkFile   = forceext(tcLinkFile, 'lnk')
lcFileToLink = fullpath(tcFileToLink)
lcDirectory  = justpath(lcFileToLink)
lnResult     = CreateShellLink(@lcLinkFile, @lcFileToLink)
lnResult     = SetLinkWorkDir(0, @lcLinkFile, @lcDirectory)
return lnResult = 0
